package com.openexchange.guard.server;

import com.openexchange.guard.config.Config;

public class Settings {
	public enum permissions {
        NONE, GUARD, MAIL, FILE, BOTH
    };
    
    public permissions perm = permissions.NONE;
    public boolean extrapass = Config.ok_extra_password;  // Set to default config level
    public boolean privatepass = true;
    public boolean noDeleteRecovery = false;
    public boolean deleteKeyOnRevoke = Config.deleteOnRetract;
    public boolean noDeletePrivate = false;
    public boolean norecovery = false;
}
